Index: trunk/MagicSoft/Mars/mbadpixels/MBadPixelsTreat.h
===================================================================
--- trunk/MagicSoft/Mars/mbadpixels/MBadPixelsTreat.h	(revision 4542)
+++ trunk/MagicSoft/Mars/mbadpixels/MBadPixelsTreat.h	(revision 4559)
@@ -27,5 +27,5 @@
         kUseCentralPixel  = 2,
         kProcessRMS       = 3,
-        kSloppyTreatment  = 4
+        kHardTreatment  = 4
     };
 
@@ -59,7 +59,7 @@
         b ? SETBIT(fFlags, kProcessRMS) : CLRBIT(fFlags, kProcessRMS);
     }
-    void SetSloppyTreatment(Bool_t b=kTRUE)
+    void SetHardTreatment(Bool_t b=kTRUE)
     {
-        b ? SETBIT(fFlags, kSloppyTreatment) : CLRBIT(fFlags, kSloppyTreatment);
+        b ? SETBIT(fFlags, kHardTreatment) : CLRBIT(fFlags, kHardTreatment);
     }
     void SetNumMinNeighbors(Byte_t num) { fNumMinNeighbors=num; }

Index: trunk/MagicSoft/Mars/mbadpixels/MBadPixelsTreat.cc
===================================================================
--- trunk/MagicSoft/Mars/mbadpixels/MBadPixelsTreat.cc	(revision 4542)
+++ trunk/MagicSoft/Mars/mbadpixels/MBadPixelsTreat.cc	(revision 4559)
@@ -38,6 +38,6 @@
 //  should be set using SetNumMinNeighbors
 //
 //  If you don't want to interpolate unreliable pixels but only unsuitable
 //  (broken) pixels use SetSloppyTreatment().
 //
 //
@@ -95,11 +95,12 @@
 // --------------------------------------------------------------------------
 //
 // Returns the status of a pixel. If kSloppyTreatment is set a pixel must
 // be unsuitable to be treated. If not it is enough if it is unreliable
 // (IsBad() checks for any flag)
 //
 Bool_t MBadPixelsTreat::IsPixelBad(Int_t idx) const
 {
-    return TESTBIT(fFlags, kSloppyTreatment) ? (*fBadPixels)[idx].IsUnsuitable() : (*fBadPixels)[idx].IsBad();
+    return TESTBIT(fFlags, kHardTreatment) ? (*fBadPixels)[idx].IsBad():(*fBadPixels)[idx].IsUnsuitable() ;
 }
 
@@ -38,6 +38,6 @@
 //  should be set using SetNumMinNeighbors
 //
-//  If you don't want to interpolate unreliable pixels but only unsuitable
-//  (broken) pixels use SetSloppyTreatment().
+//  If you want to interpolate unreliable pixels and  unsuitable
+//  (broken) pixels use SetHardTreatment().
 //
 //
@@ -95,11 +95,12 @@
 // --------------------------------------------------------------------------
 //
-// Returns the status of a pixel. If kSloppyTreatment is set a pixel must
-// be unsuitable to be treated. If not it is enough if it is unreliable
+// Returns the status of a pixel. If kHardTreatment is set a pixel must
+// be unsuitable or uriliable to be treated. If not it is treated only if 
+// it is unsuitable
 // (IsBad() checks for any flag)
 //